#!/usr/bin/perl -w

# $Id: reblog_install.cgi,v 1.2 2005/05/24 21:01:27 mfrumin Exp $
#
# This file is part of Reblog: http://reblog.org
# Distributed under the Gnu Public License, see LICENSE
#
# Copyright 2004 Michael Frumin, Michal Migurski
# This is the Movable Type Plugin code to implement the reBlog functionality into Movable Type
#
# Developed by Michael Frumin (mfrumin AT eyebeam DOT org)
# Initially for Eyebeam's reBlog (http://www.eyebeam.org/reblog/)
#
# NOTE: This only works if you are using MySQL for the database backend for Movable Type
  
  
use strict;
use File::Spec;

my($MT_DIR);
BEGIN {
    if (0 && $0 =~ m!(.*[/\\])!) {
        $MT_DIR = $1;
    } else {
	$MT_DIR = $ENV{SCRIPT_FILENAME};
    }

    # back up to directory just above 'plugins'
    my ($vol, $dir, $f) = File::Spec->splitpath($MT_DIR);
    my (@dirs) = File::Spec->splitdir($dir);
    while(pop(@dirs) ne 'plugins' && scalar(@dirs) > 0){};
    push(@dirs, "");
    $MT_DIR = File::Spec->join(@dirs);
    
    unshift @INC, $MT_DIR . 'lib';
    unshift @INC, $MT_DIR . 'extlib';
}

eval {
    require MT::App::CMS;
    my $app = MT::App::CMS->new( Config => $MT_DIR . 'mt.cfg',
                                 Directory => $MT_DIR )
        or die MT::App::CMS->errstr;
    local $SIG{__WARN__} = sub { $app->trace($_[0]) };

    my $cgi = $app->{query};

    my ($auth) = $app->login();

    if(!(defined($auth) && $auth)) {
	print $cgi->redirect($app->path . "mt.cgi");
	exit;
    }

    if(!ref($auth)) {
	$auth = MT::Author->load($auth);
    }


    $app->send_http_header;

    use MT::Util qw( encode_html );

    my $back_url = $cgi->param("back") || $ENV{HTTP_REFERER} || "";

    require MT::App::CMS;
    my $header = MT::App::CMS::build_page ($app, "header.tmpl", { author_name => $auth->username, no_breadcrumbs => 1 }) || "";
    my $footer = MT::App::CMS::build_page ($app, "footer.tmpl", {}) || "";

    print $header;

    my $back = ($back_url ? qq{&lt;&lt;&lt;&nbsp;<a href="} . encode_html($back_url) . qq{">go back from whence you came</a>} : "");

    my ($status, $version) = MT::Plugin::Reblog::check_reblog_status();

    if($status eq '-install') {
	do_install();
    }
    else {
	print qq{Sorry, the reBlog plugin is already installed.<BR>};
    }

    print qq{<BR>&lt;&lt;&lt;&nbsp;<a href="../mt.cgi">Back to Movable Type</a><BR>\n};
    print ($back ? "<BR>$back<BR>" : "");
    print $footer;

};
if ($@) {
    print STDERR "ERROR: $@\n";
    print "Content-Type: text/html\n\n";
    print "Got an error: <BR><PRE>" . encode_html($@) . "</PRE>";
}

sub do_install {
    my $driver = MT::Object->driver();
    my $dbh = $driver->{dbh};
    my $ds = MT::ReblogData->datasource;
    
    print "INSTALLING<BR>\n";

    print MT::Plugin::Reblog::create_reblog_data_table($dbh, $ds);

    print "INSTALLED<BR>\n";

}

